#
# spec file for package synfig
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname libsynfig
%define sover 0
%bcond_without ffmpeg
%bcond_without fontconfig
%bcond_without freetype
%bcond_without imagemagick
%bcond_without jpeg
%bcond_with    libavcodec
%bcond_with    libswscale
%bcond_without magickpp
%bcond_without openexr
%bcond_without libdv
Name:           synfig
Version:        1.2.0
Release:        pm152.3.11
Summary:        Vector based 2D animation render
License:        GPL-3.0+
Group:          Productivity/Graphics/Other
Url:            http://synfig.org
Source0:        https://sourceforge.net/projects/synfig/files/releases/%{version}/source/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE debug.patch avvissu@yandex.by -- Specify the `-g' option when building
Patch0:         synfig-1.0.2_debug.patch
Patch1:         synfig.gcc7.patch
Patch2:         synfig.magick7.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libmng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig(ETL)
BuildRequires:  pkgconfig(cairo) >= 1.12.0
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(giomm-2.4) >= 2.18.2
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.24.2
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  pkgconfig(mlt++)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with imagemagick}
BuildRequires:  pkgconfig(ImageMagick)
%endif
%if %{with jpeg}
BuildRequires:  libjpeg-devel
%endif
%if %{with magickpp}
BuildRequires:  pkgconfig(Magick++) >= 6.4.2
%endif
%if %{with openexr}
BuildRequires:  pkgconfig(OpenEXR)
%endif
%if %{with fontconfig}
BuildRequires:  pkgconfig(fontconfig)
%endif
%if %{with freetype}
BuildRequires:  pkgconfig(freetype2)
%endif
%if %{with libavcodec}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
%endif
%if %{with libswscale}
BuildRequires:  pkgconfig(libswscale)
%endif
%if %{with libdv}
BuildRequires:  pkgconfig(libdv)
%endif

%description
%{summary}.

This package contains the command line renderer used to convert synfig .sif 
files to raster images, videos and other formats. Layer types include 
geometric, gradient, filter, distortion, transformation, fractal and 
others.

%package -n     %{soname}%{sover}
Summary:        Shared library part of %{name}
Group:          System/Libraries
Requires:       %{name}-modules >= %{version}

%description -n %{soname}%{sover}
Vector based 2D animation render.

This package contains the shared library.

%package        modules
Summary:        Shared library part of %{name}
Group:          System/Libraries
Requires:       %{name} = %{version}

%description    modules
Vector based 2D animation render.

This package contains modules for %{name}.

%package        devel
Summary:        Header files and static library for the %{name} library
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}
Provides:       %{soname}-devel = %{version}
Obsoletes:      %{soname}-devel < %{version}

%description    devel
Vector based 2D animation render.

This package contains the pkgconfig, header files and libraries needed to
develop application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
Vector based 2D animation render.

This package provides documentation and several examples for %{name}.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Don't compile in DATE and TIME
BUILDDATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%b %d %Y')
BUILDTIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%H:%M')
sed -e "s/__DATE__/\"$BUILDDATE\"/" \
    -e "s/__TIME__/\"$BUILDTIME\"/" \
    -i $(grep -rl '__DATE__\|__TIME__')

%build
autoreconf -fiv
%configure \
    %{!?with_ffmpeg:--without-ffmpeg} \
    %{!?with_fontconfig:--without-fontconfig} \
    %{!?with_freetype:--without-freetype} \
    %{!?with_jpeg:--without-jpeg} \
    %{!?with_imagemagick:--without-imagemagick} \
    %{?with_libavcodec:--with-libavcodec} \
    %{!?with_libswscale:--without-libswscale} \
    %{!?with_magickpp:--without-magickpp} \
    %{!?with_openexr:--without-openexr} \
    %{!?with_libdv:--without-libdv} \
    --sysconfdir=%{_sysconfdir}/%{name}

make %{?_smp_mflags}

%install
%make_install

%find_lang %{name} %{?no_lang_C} --without-gnome --without-kde

find {doc,examples} -type f ! -iname \make* -exec \
install -Dm0644 \{\} %{buildroot}%{_docdir}/%{name}/\{\} \;

find %{buildroot} -type f -name \*.la -exec rm -f \{\} \;

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING NEWS README TODO
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/%{name}*.cfg
%exclude %{_docdir}/%{name}/doc
%exclude %{_docdir}/%{name}/examples

%files -n %{soname}%{sover}
%defattr(-,root,root)
%{_libdir}/%{soname}.so.*

%files modules
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/*.so

%files devel
%defattr(-,root,root)
%{_bindir}/%{name}-config
%{_includedir}/%{name}*/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/doc/
%{_docdir}/%{name}/examples/

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Wed Jan 11 2017 avvissu@yandex.by
- Update to 1.2.0:
  * see: /usr/share/doc/packages/synfig/NEWS
- Drop patches (fixed in upstream):
  * synfig-1.0.2_c++11.patch
  * synfig-isnan.patch
  * synfig-math_h.patch
* Sat Apr  2 2016 avvissu@yandex.by
- Update to 1.0.2:
  * see: /usr/share/doc/packages/synfig/NEWS
- Remove patches:
  * synfig-devel-deps.patch	(fixed in upstream)
  * synfig-intltoolize.patch (use autoreconf only)
  * synfig-lyr_freetype.patch (fixed in upstream)
  * synfig-no-buildtime.patch (use sed in spec-file)
- Update patches:
  * synfig-configure-debug.patch -> synfig-1.0.2_debug.patch
- Add patches:
  * synfig-1.0.2_c++11.patch
- Build witch support libdv
- Create the new package: modules, doc
- Cleanup the descriptions for packages
- Spec-file cleanup
* Mon Jun 22 2015 olaf@aepfle.de
- update to 1.0
* Tue Nov  5 2013 obs@botter.cc
- update to 0.64.1
* Sun Apr 15 2012 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.05-0
- update to 0.63.05
* Mon Oct 24 2011 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.02-0.pm.1
- update to 0.63.02
* Sat Jun 11 2011 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.00-0.pm.1
- update to 0.63.00 (git logout, because there's no source tarball)
* Mon Nov 15 2010 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.02-1.pm.1
- update to 0.62.02
* Wed Jul 14 2010 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.01-1.pm.1
- update to 0.62.01
* Wed Nov  4 2009 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.00-0.pm.1
- update to 0.62.00
* Wed Sep 23 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.61.09-1.pm.4
- added patch to compile it with gcc 4.4 (openSUSE 11.2)
* Sat Sep  5 2009 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.61.09-1.pm.1
- cleanups where rpmlint wasn't so happy
* Sat Jan  3 2009 Manfred.Tremmel@iiv.de
- remove NX in 11.1, it's no longer available
* Sat Oct 25 2008 Manfred.Tremmel@iiv.de
- update to 0.61.09
* Tue Sep 16 2008 Manfred.Tremmel@iiv.de
- recompile against new ffmpeg version
* Tue Mar  4 2008 Manfred.Tremmel@iiv.de
- update to 0.61.08
* Sat Feb 23 2008 Manfred.Tremmel@iiv.de
- update to svn (Revision 1808), because off security reasons
* Thu Dec 20 2007 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- added patch to make it work with latest ffmpeg version
* Fri Oct 12 2007 Manfred.Tremmel@iiv.de
- update to 0.61.07
* Sat Jun 23 2007 Manfred.Tremmel@iiv.de
- update to 0.61.06
* Sun Dec 24 2006 Manfred.Tremmel@iiv.de
- update to svn (Revision 229), seems, a lot of bugs where fixed inbetween
* Thu Dec 21 2006 Manfred.Tremmel@iiv.de
- recompile with new libffmpeg version
* Wed Mar  1 2006 Manfred.Tremmel@iiv.de
- update to 0.61.05
* Mon Jan 23 2006 Manfred.Tremmel@iiv.de
- recompile with new libffmpeg version
* Sun Jan 15 2006 Manfred.Tremmel@iiv.de
- update to 0.61.04
* Thu Dec 15 2005 Manfred.Tremmel@iiv.de
- first packman build, based on the spec-file
  from Robert B. Quattlebaum Jr. <darco@bigfoot.com>
